@@ -22,11 +22,14 @@
 
 #include "custom_app.h"
 
-#include <sstream>
+#include "local_i18n.h"
 
 #include <GL/gl.h>
 #include <GL/glu.h>
 
+#include <sstream>
+using namespace std;
+
 /*################################################################################################*/
 
 eldview_wcl::eldview_wcl(void) :
@@ -156,12 +159,12 @@ void eldview_wcl::RenderGL(rmode)
 		GLfloat xpos;
 		GLfloat ypos;
 		
-		const char * txt1 = "No data available,";
+		const char * txt1 = _("No data available,");
 		xpos = (wnd->GetWidth() - ogl_GetStringWidth(txt1)) / 2.0;
 		ypos = (wnd->GetHeight() - 24) / 2.0 + 14;
 		ogl_WriteString2D(txt1, xpos, ypos);
 		
-		const char * txt2 = (nonQM ? "must be a QM model!" : "please calculate energy!");
+		const char * txt2 = (nonQM ? _("must be a QM model!") : _("please calculate energy!"));
 		xpos = (wnd->GetWidth() - ogl_GetStringWidth(txt2)) / 2.0;
 		ypos = (wnd->GetHeight() - 24) / 2.0 - 14;
 		ogl_WriteString2D(txt2, xpos, ypos);
